@@ -1,5 +1,4 @@
 from dataclasses import dataclass
-from dataclasses_json import dataclass_json, LetterCase
 
 # {
 #     "name": "review",
@@ -12,7 +11,6 @@ from dataclasses_json import dataclass_json, LetterCase
 # },
 
 
-@dataclass_json(letter_case=LetterCase.CAMEL)
 @dataclass
 class TableColumnInfo:
     name: str
