@@ -40,8 +40,9 @@ class MlPlatformApi:
             self.mount_path = self.api_client.pvc_mount_path
             if "servingMountPath" in os.environ:
                 # shutil.rmtree(os.environ["mount_path"])
+                self.serving_mount_path = os.environ["servingMountPath"]
                 Path(os.path.dirname(self.mount_path)).mkdir(parents=True, exist_ok=True)
-                os.symlink(os.environ["servingMountPath"], self.mount_path)
+                os.symlink(self.serving_mount_path, self.mount_path)
             else:
                 Path(self.get_experiment_path()).mkdir(parents=True, exist_ok=True)
                 Path(self.get_train_path()).mkdir(parents=True, exist_ok=True)
